Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(934)

Unified Diff: content/common/view_messages.h

Issue 103583005: Restart fullscreen video playback when switching back from background (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/common/view_messages.h
diff --git a/content/common/view_messages.h b/content/common/view_messages.h
index 4ad62ce9b57811506a61cc1b46d04c8498a692a3..6bcf8ed62f3293fe6d839e31da848f06c9df41e4 100644
--- a/content/common/view_messages.h
+++ b/content/common/view_messages.h
@@ -1349,8 +1349,9 @@ IPC_MESSAGE_ROUTED1(ViewMsg_BeginFrame,
// processed on the browser side.
IPC_MESSAGE_ROUTED0(ViewMsg_ImeEventAck)
// Sent by the browser when we should pause video playback.
qinmin 2013/12/06 00:10:13 pause is for all the videos, and resume is only fo
IPC_MESSAGE_ROUTED0(ViewMsg_PauseVideo);
+IPC_MESSAGE_ROUTED0(ViewMsg_ResumeVideo);
qinmin 2013/12/06 00:10:13 s/ResumeVideo/ResumeFullscreenVideo/
#elif defined(OS_MACOSX)
// Let the RenderView know its window has changed visibility.
@@ -1349,8 +1349,9 @@ IPC_MESSAGE_ROUTED1(ViewMsg_BeginFrame,
// processed on the browser side.
IPC_MESSAGE_ROUTED0(ViewMsg_ImeEventAck)
-// Sent by the browser when we should pause video playback.
+// Sent by the browser when we should pause/resume video playback.
qinmin 2013/12/06 00:10:13 pause is for all the videos, and resume is only fo
IPC_MESSAGE_ROUTED0(ViewMsg_PauseVideo);

Powered by Google App Engine
This is Rietveld 408576698